# coding: utf-8

from __future__ import absolute_import

from ruamel_yaml.ext._ruamel_yaml import CParser, CEmitter

try:
    from .constructor import *                               # NOQA
    from .serializer import *                               # NOQA
    from .representer import *                               # NOQA
    from .resolver import *                               # NOQA
except (ImportError, ValueError):  # for Jython
    from ruamel_yaml.constructor import *                               # NOQA
    from ruamel_yaml.serializer import *                               # NOQA
    from ruamel_yaml.representer import *                               # NOQA
    from ruamel_yaml.resolver import *                               # NOQA

__all__ = ['CBaseLoader', 'CSafeLoader', 'CLoader',
           'CBaseDumper', 'CSafeDumper', 'CDumper']


class CBaseLoader(CParser, BaseConstructor, BaseResolver):
    def __init__(self, stream, version=None):
        CParser.__init__(self, stream)
        BaseConstructor.__init__(self)
        BaseResolver.__init__(self)


class CSafeLoader(CParser, SafeConstructor, Resolver):
    def __init__(self, stream, version=None):
        CParser.__init__(self, stream)
        SafeConstructor.__init__(self)
        Resolver.__init__(self)


class CLoader(CParser, Constructor, Resolver):
    def __init__(self, stream, version=None, preserve_quotes=None):
        CParser.__init__(self, stream)
        Constructor.__init__(self)
        Resolver.__init__(self)


class CBaseDumper(CEmitter, BaseRepresenter, BaseResolver):
    def __init__(self, stream,
                 default_style=None, default_flow_style=None,
                 canonical=None, indent=None, width=None,
                 allow_unicode=None, line_break=None,
                 encoding=None, explicit_start=None, explicit_end=None,
                 version=None, tags=None):
        CEmitter.__init__(self, stream, canonical=canonical,
                          indent=indent, width=width, encoding=encoding,
                          allow_unicode=allow_unicode, line_break=line_break,
                          explicit_start=explicit_start,
                          explicit_end=explicit_end,
                          version=version, tags=tags)
        Representer.__init__(self, default_style=default_style,
                             default_flow_style=default_flow_style)
        Resolver.__init__(self)


class CSafeDumper(CEmitter, SafeRepresenter, Resolver):
    def __init__(self, stream,
                 default_style=None, default_flow_style=None,
                 canonical=None, indent=None, width=None,
                 allow_unicode=None, line_break=None,
                 encoding=None, explicit_start=None, explicit_end=None,
                 version=None, tags=None):
        CEmitter.__init__(self, stream, canonical=canonical,
                          indent=indent, width=width, encoding=encoding,
                          allow_unicode=allow_unicode, line_break=line_break,
                          explicit_start=explicit_start,
                          explicit_end=explicit_end,
                          version=version, tags=tags)
        SafeRepresenter.__init__(self, default_style=default_style,
                                 default_flow_style=default_flow_style)
        Resolver.__init__(self)


class CDumper(CEmitter, Serializer, Representer, Resolver):
    def __init__(self, stream,
                 default_style=None, default_flow_style=None,
                 canonical=None, indent=None, width=None,
                 allow_unicode=None, line_break=None,
                 encoding=None, explicit_start=None, explicit_end=None,
                 version=None, tags=None):
        CEmitter.__init__(self, stream, canonical=canonical,
                          indent=indent, width=width, encoding=encoding,
                          allow_unicode=allow_unicode, line_break=line_break,
                          explicit_start=explicit_start,
                          explicit_end=explicit_end,
                          version=version, tags=tags)
        Representer.__init__(self, default_style=default_style,
                             default_flow_style=default_flow_style)
        Resolver.__init__(self)



# coding: utf-8

from __future__ import absolute_import

__all__ = ['BaseLoader', 'SafeLoader', 'Loader', 'RoundTripLoader']

try:
    from .reader import *                                # NOQA
    from .scanner import *                               # NOQA
    from .parser import *                                # NOQA
    from .composer import *                              # NOQA
    from .constructor import *                           # NOQA
    from .resolver import *                              # NOQA
except (ImportError, ValueError):  # for Jython
    from ruamel_yaml.reader import *                                # NOQA
    from ruamel_yaml.scanner import *                               # NOQA
    from ruamel_yaml.parser import *                                # NOQA
    from ruamel_yaml.composer import *                              # NOQA
    from ruamel_yaml.constructor import *                           # NOQA
    from ruamel_yaml.resolver import *                              # NOQA


class BaseLoader(Reader, Scanner, Parser, Composer, BaseConstructor, BaseResolver):
    def __init__(self, stream, version=None, preserve_quotes=None):
        Reader.__init__(self, stream)
        Scanner.__init__(self)
        Parser.__init__(self)
        Composer.__init__(self)
        BaseConstructor.__init__(self)
        BaseResolver.__init__(self)


class SafeLoader(Reader, Scanner, Parser, Composer, SafeConstructor, Resolver):
    def __init__(self, stream, version=None, preserve_quotes=None):
        Reader.__init__(self, stream)
        Scanner.__init__(self)
        Parser.__init__(self)
        Composer.__init__(self)
        SafeConstructor.__init__(self)
        Resolver.__init__(self)


class Loader(Reader, Scanner, Parser, Composer, Constructor, Resolver):
    def __init__(self, stream, version=None, preserve_quotes=None):
        Reader.__init__(self, stream)
        Scanner.__init__(self)
        Parser.__init__(self)
        Composer.__init__(self)
        Constructor.__init__(self)
        Resolver.__init__(self)


class RoundTripLoader(Reader, RoundTripScanner, RoundTripParser, Composer,
                      RoundTripConstructor, VersionedResolver):
    def __init__(self, stream, version=None, preserve_quotes=None):
        Reader.__init__(self, stream)
        RoundTripScanner.__init__(self)
        RoundTripParser.__init__(self)
        Composer.__init__(self)
        RoundTripConstructor.__init__(self, preserve_quotes=preserve_quotes)
        VersionedResolver.__init__(self, version)
